@@ -35,7 +35,7 @@ def generate(obj, file: str, template: str, artwork: str = None, season: str = N
     - Season: -s is set and -e is not.
     - Episode: -e is set. -s can be set or not though it's recommended.
     """
-    if season.isdigit():
+    if season is not None and season.isdigit():
         season = int(season)
 
     nfo = NFO()
@@ -44,7 +44,9 @@ def generate(obj, file: str, template: str, artwork: str = None, season: str = N
     if config.exists():
         with config.open() as f:
             nfo.set_config(
-                str(Path(file).resolve()), season, episode,
+                str(Path(file).resolve()),
+                season,
+                episode,
                 **dict(
                     imdb=imdb,
                     tmdb=tmdb,
@@ -57,10 +59,10 @@ def generate(obj, file: str, template: str, artwork: str = None, season: str = N
             )
 
     template_vars = {
-        "videos": nfo.get_video_print(nfo.videos),
-        "audios": nfo.get_audio_print(nfo.audio),
-        "subtitles": nfo.get_subtitle_print(nfo.subtitles),
-        "chapters": nfo.get_chapter_print_short(nfo.chapters),
+        "videos_pretty": nfo.get_video_print(nfo.videos),
+        "audio_pretty": nfo.get_audio_print(nfo.audio),
+        "subtitles_pretty": nfo.get_subtitle_print(nfo.subtitles),
+        "chapters_yes_no": nfo.get_chapter_print_short(nfo.chapters),
         "chapters_named": nfo.chapters and not nfo.chapters_numbered,
         "chapter_entries": nfo.get_chapter_print(nfo.chapters)
     }
